@@ -84,6 +84,22 @@ typedef enum {
 	FU_PATH_KIND_LAST
 } FuPathKind;
 
+/**
+ * FuCpuVendor:
+ * @FU_CPU_VENDOR_UNKNOWN:		Unknown
+ * @FU_CPU_VENDOR_INTEL:		Intel
+ * @FU_CPU_VENDOR_AMD:			AMD
+ *
+ * The CPU vendor.
+ **/
+typedef enum {
+	FU_CPU_VENDOR_UNKNOWN,
+	FU_CPU_VENDOR_INTEL,
+	FU_CPU_VENDOR_AMD,
+	/*< private >*/
+	FU_CPU_VENDOR_LAST
+} FuCpuVendor;
+
 typedef void	(*FuOutputHandler)		(const gchar	*line,
 						 gpointer	 user_data);
 
@@ -92,41 +108,53 @@ gboolean	 fu_common_spawn_sync		(const gchar * const *argv,
 						 gpointer	 handler_user_data,
 						 guint		 timeout_ms,
 						 GCancellable	*cancellable,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 
 gchar		*fu_common_get_path		(FuPathKind	 path_kind);
 gchar		*fu_common_realpath		(const gchar	*filename,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray	*fu_common_filename_glob	(const gchar	*directory,
 						 const gchar	*pattern,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_fnmatch		(const gchar	*pattern,
 						 const gchar	*str);
 gboolean	 fu_common_rmtree		(const gchar	*directory,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray	*fu_common_get_files_recursive	(const gchar	*path,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_mkdir_parent		(const gchar	*filename,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_set_contents_bytes	(const gchar	*filename,
 						 GBytes		*bytes,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GBytes		*fu_common_get_contents_bytes	(const gchar	*filename,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GBytes		*fu_common_get_contents_fd	(gint		 fd,
 						 gsize		 count,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_extract_archive	(GBytes		*blob,
 						 const gchar	*dir,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GBytes		*fu_common_firmware_builder	(GBytes		*bytes,
 						 const gchar	*script_fn,
 						 const gchar	*output_fn,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GError		*fu_common_error_array_get_best	(GPtrArray	*errors);
 guint64		 fu_common_strtoull		(const gchar	*str);
 gchar		*fu_common_find_program_in_path	(const gchar	*basename,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gchar		*fu_common_strstrip		(const gchar	*str);
 void		 fu_common_dump_raw		(const gchar	*log_domain,
 						 const gchar	*title,
@@ -147,15 +175,26 @@ GBytes		*fu_common_bytes_align		(GBytes		*bytes,
 gboolean	 fu_common_bytes_is_empty	(GBytes		*bytes);
 gboolean	 fu_common_bytes_compare	(GBytes		*bytes1,
 						 GBytes		*bytes2,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_bytes_compare_raw	(const guint8	*buf1,
 						 gsize		 bufsz1,
 						 const guint8	*buf2,
 						 gsize		 bufsz2,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GBytes		*fu_common_bytes_pad		(GBytes		*bytes,
 						 gsize		 sz);
+GBytes		*fu_common_bytes_new_offset	(GBytes		*bytes,
+						 gsize		 offset,
+						 gsize		 length,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gsize		 fu_common_strwidth		(const gchar	*text);
+guint8		*fu_memdup_safe			(const guint8	*src,
+						 gsize		 n,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_memcpy_safe			(guint8		*dst,
 						 gsize		 dst_sz,
 						 gsize		 dst_offset,
@@ -163,24 +202,62 @@ gboolean	 fu_memcpy_safe			(guint8		*dst,
 						 gsize		 src_sz,
 						 gsize		 src_offset,
 						 gsize		 n,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_read_uint8_safe	(const guint8	*buf,
 						 gsize		 bufsz,
 						 gsize		 offset,
 						 guint8		*value,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_read_uint16_safe	(const guint8	*buf,
 						 gsize		 bufsz,
 						 gsize		 offset,
 						 guint16	*value,
 						 FuEndianType	 endian,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 fu_common_read_uint32_safe	(const guint8	*buf,
 						 gsize		 bufsz,
 						 gsize		 offset,
 						 guint32	*value,
 						 FuEndianType	 endian,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_read_uint64_safe	(const guint8	*buf,
+						 gsize		 bufsz,
+						 gsize		 offset,
+						 guint64	*value,
+						 FuEndianType	 endian,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_write_uint8_safe	(guint8		*buf,
+						 gsize		 bufsz,
+						 gsize		 offset,
+						 guint8		 value,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_write_uint16_safe	(guint8		*buf,
+						 gsize		 bufsz,
+						 gsize		 offset,
+						 guint16	 value,
+						 FuEndianType	 endian,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_write_uint32_safe	(guint8		*buf,
+						 gsize		 bufsz,
+						 gsize		 offset,
+						 guint32	 value,
+						 FuEndianType	 endian,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_write_uint64_safe	(guint8		*buf,
+						 gsize		 bufsz,
+						 gsize		 offset,
+						 guint64	 value,
+						 FuEndianType	 endian,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 
 void		 fu_byte_array_set_size		(GByteArray	*array,
 						 guint		 length);
@@ -192,6 +269,9 @@ void		 fu_byte_array_append_uint16	(GByteArray	*array,
 void		 fu_byte_array_append_uint32	(GByteArray	*array,
 						 guint32	 data,
 						 FuEndianType	 endian);
+void		 fu_byte_array_append_uint64	(GByteArray	*array,
+						 guint64	 data,
+						 FuEndianType	 endian);
 
 void		 fu_common_write_uint16		(guint8		*buf,
 						 guint16	 val_native,
@@ -199,10 +279,15 @@ void		 fu_common_write_uint16		(guint8		*buf,
 void		 fu_common_write_uint32		(guint8		*buf,
 						 guint32	 val_native,
 						 FuEndianType	 endian);
+void		 fu_common_write_uint64		(guint8		*buf,
+						 guint64	 val_native,
+						 FuEndianType	 endian);
 guint16		 fu_common_read_uint16		(const guint8	*buf,
 						 FuEndianType	 endian);
 guint32		 fu_common_read_uint32		(const guint8	*buf,
 						 FuEndianType	 endian);
+guint64		 fu_common_read_uint64		(const guint8	*buf,
+						 FuEndianType	 endian);
 
 guint		 fu_common_string_replace	(GString	*string,
 						 const gchar	*search,
@@ -227,20 +312,37 @@ gchar		**fu_common_strnsplit		(const gchar	*str,
 						 gsize		 sz,
 						 const gchar	*delimiter,
 						 gint		 max_tokens);
+gchar		*fu_common_strsafe		(const gchar	*str,
+						 gsize		 maxsz);
+gchar		*fu_common_strjoin_array	(const gchar	*separator,
+						 GPtrArray	*array);
 gboolean	 fu_common_kernel_locked_down	(void);
 gboolean	 fu_common_cpuid		(guint32	 leaf,
 						 guint32	*eax,
 						 guint32	*ebx,
 						 guint32	*ecx,
 						 guint32	*edx,
-						 GError		**error);
-gboolean	 fu_common_is_cpu_intel		(void);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 fu_common_is_cpu_intel		(void)
+G_DEPRECATED_FOR(fu_common_get_cpu_vendor);
+FuCpuVendor	 fu_common_get_cpu_vendor	(void);
 gboolean	 fu_common_is_live_media	(void);
+guint64		 fu_common_get_memory_size	(void);
 GPtrArray	*fu_common_get_volumes_by_kind	(const gchar	*kind,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+FuVolume	*fu_common_get_volume_by_device (const gchar	*device,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+FuVolume	*fu_common_get_volume_by_devnum	(guint32	 devnum,
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 FuVolume	*fu_common_get_esp_for_path	(const gchar	*esp_path,
-						 GError		**error);
-FuVolume	*fu_common_get_esp_default	(GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
+FuVolume	*fu_common_get_esp_default	(GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 
 guint8		 fu_common_crc8			(const guint8	*buf,
 						 gsize		 bufsz);
@@ -252,3 +354,4 @@ guint32		 fu_common_crc32_full		(const guint8	*buf,
 						 gsize		 bufsz,
 						 guint32	 crc,
 						 guint32	 polynomial);
+gchar		*fu_common_uri_get_scheme	(const gchar	*uri);
